---
title: <span class="badge builder"></span> Metadata
---
# <span class="badge builder"></span> Metadata

## Constructor

```python
Metadata()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> resource.Metadata
```

### <span class="badge object-method"></span> annotations

```python
def annotations(annotations: dict[str, str]) -> typing.Self
```

### <span class="badge object-method"></span> creation_timestamp

```python
def creation_timestamp(creation_timestamp: str) -> typing.Self
```

### <span class="badge object-method"></span> deletion_timestamp

```python
def deletion_timestamp(deletion_timestamp: str) -> typing.Self
```

### <span class="badge object-method"></span> generation

```python
def generation(generation: int) -> typing.Self
```

### <span class="badge object-method"></span> labels

```python
def labels(labels: dict[str, str]) -> typing.Self
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> namespace

```python
def namespace(namespace: str) -> typing.Self
```

### <span class="badge object-method"></span> resource_version

```python
def resource_version(resource_version: str) -> typing.Self
```

### <span class="badge object-method"></span> uid

```python
def uid(uid: str) -> typing.Self
```

### <span class="badge object-method"></span> update_timestamp

```python
def update_timestamp(update_timestamp: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Metadata](./object-Metadata.md)
